Следующее урпжанение – это агрегация. Агрегация позваоляет делать такие вещи, 
как например вычисление суммы конкретного поля множеств документов или среднее
арифметическое поля документов, удовлетворяющих определенному критерию.

Скажем, у вас есть коллекция `prices` (цены). Каждый документ цены сделан 
таким образом:

```js
{
  "name": "Tshirt",
  "size": "S",
  "price": 10,
  "quantity": 12
  "meta": {
    "vendor": "hanes",
    "location": "US"
  }
}
```

В этом упражнении нам нужно подсчитать среднее арифметическое для всех документов
в коллекции `prices` в базе данных `learnyoumongo`. Нужно будет выбрать только 
те документы, у которых размер (size) будет такой как указано в первом аргументе
вашего скрипта.

Используйте `console.log()` для печати средней цены. Округлите её до 2-х знаков 
после запятой.

-----------------------------------------------------------
## ПОДСКАЗКИ

Чтобы использовать функцию `aggregate()`, вам для начала нужна коллекция.
Функция `aggregate()` принимает массив объектов в качестве первого аргумента.

Этот массив будет содержать различные этапы процесса обработки для агрегации.
Чтобы узнать больше про эти процессы обработки, посетите страницу 
[Aggregation](http://docs.mongodb.org/manual/core/aggregation-introduction/).

The two main pipeline stages we will use will be `$match` and `$group`.

### $match

`$match` используется похожим путем как и с обычным запрсом. Он позволяет нам 
выбрать документы, которые удовлетворяют выбранным критериям.

Пример

```js
var match = { $match: { status: 'A' } }
```

Пример сверху соответствует всем документам, которые имеют свойство `status`
равное `A`.

### $group

`$group` – это то, что позволяет нам выполнять операции на выбранных свойствах.

Докустим, мы хотим получить сумму значений свойства `value`
где `status` равен `A` и хотим разместить её в свойстве `total`.

Пример

```js
// [
//  { status: 'A', value: 1 },
//  { status: 'B', value: 2 },
//  { status: 'A', value: 10 }
// ]

collection.aggregate([
  { $match: { status: 'A' }}
, { $group: {
    _id: 'total' // вообще, в данном случае здесь может быть произвольная строка
  , total: {
      // $sum – это оператор используемый в примере
      $sum: '$value'
    }
  }}
]).toArray(function(err, results) {
  // обработка ошибки
  console.log(results)
  // => [
  // =>   { _id: 'total', total: 11 }
  // => ]
})
```
Другие операторы используемые в стадии `$group` включают:

- `$avg` (среднее арифметическое)
- `$first` (первый)
- `$last` (последний)
- `$max` (максимум)
- `$min` (минимум)
- `$push` (поместить)
- `$addToSet` (добавить в множество)

# Округление

Прототип `Number` содержит функцию `toFixed()`, которая принимает количество 
десятичных знаков, до которых вы хотите округлить, и возвращает строковое представление.

```js
var value = "1"
Number(value).toFixed(5)
// => '1.00000'
```

Если ваша программа не будет заканчивать выполнение, то вы вероятно забыли закрыть `db`. 
Это можно сделать путем вызова метода `db.close()` после того как вы закончите.

## Ресурсы
* http://docs.mongodb.org/manual/aggregation/
* http://docs.mongodb.org/manual/core/aggregation-introduction/
